(function() {
  var BASE_URI, Gauges, request;

  request = require('request');

  BASE_URI = 'https://secure.gaug.es';

  Gauges = (function() {

    function Gauges(options) {
      this.options = options;
    }

    Gauges.prototype.me = function(cb) {
      return this.get('/me', {}, cb);
    };

    Gauges.prototype.updateMe = function(params, cb) {
      if (params == null) params = {};
      return this.put('/me', params, cb);
    };

    Gauges.prototype.clients = function(cb) {
      return this.get('/clients', {}, cb);
    };

    Gauges.prototype.createClient = function(params, cb) {
      if (params == null) params = {};
      return this.post('/clients', params, cb);
    };

    Gauges.prototype.deleteClient = function(id, cb) {
      return this["delete"]("/clients/" + id, cb);
    };

    Gauges.prototype.gauges = function(cb) {
      return this.get('/gauges', {}, cb);
    };

    Gauges.prototype.createGauge = function(params, cb) {
      if (params == null) params = {};
      return this.post('/gauges', params, cb);
    };

    Gauges.prototype.gauge = function(id, cb) {
      return this.get("/gauges/" + id, {}, cb);
    };

    Gauges.prototype.updateGauge = function(id, params, cb) {
      if (params == null) params = {};
      return this.put("/gauges/" + id, params, cb);
    };

    Gauges.prototype.deleteGauge = function(id, cb) {
      return this["delete"]("/gauges/" + id, cb);
    };

    Gauges.prototype.shares = function(id, cb) {
      return this.get("/gauges/" + id + "/shares", {}, cb);
    };

    Gauges.prototype.share = function(id, params, cb) {
      if (params == null) params = {};
      return this.post("/gauges/" + id + "/shares", params, cb);
    };

    Gauges.prototype.unshare = function(id, user_id, cb) {
      return this["delete"]("/gauges/" + id + "/shares/" + user_id, cb);
    };

    Gauges.prototype.content = function(id, params, cb) {
      if (params == null) params = {};
      return this.get("/gauges/" + id + "/content", params, cb);
    };

    Gauges.prototype.referrers = function(id, params, cb) {
      if (params == null) params = {};
      return this.get("/gauges/" + id + "/referrers", params, cb);
    };

    Gauges.prototype.traffic = function(id, params, cb) {
      if (params == null) params = {};
      return this.get("/gauges/" + id + "/traffic", params, cb);
    };

    Gauges.prototype.resolutions = function(id, params, cb) {
      if (params == null) params = {};
      return this.get("/gauges/" + id + "/resolutions", params, cb);
    };

    Gauges.prototype.technology = function(id, params, cb) {
      if (params == null) params = {};
      return this.get("/gauges/" + id + "/technology", params, cb);
    };

    Gauges.prototype.terms = function(id, params, cb) {
      if (params == null) params = {};
      return this.get("/gauges/" + id + "/terms", params, cb);
    };

    Gauges.prototype.engines = function(id, params, cb) {
      if (params == null) params = {};
      return this.get("/gauges/" + id + "/engines", params, cb);
    };

    Gauges.prototype.locations = function(id, params, cb) {
      if (params == null) params = {};
      return this.get("/gauges/" + id + "/locations", params, cb);
    };

    Gauges.prototype.token = function() {
      return this.options.token;
    };

    Gauges.prototype.get = function(path, params, cb) {
      if (params == null) params = {};
      return request.get(this.fullPath(path), this.reqOptions({
        qs: params
      }), function(err, res) {
        return cb(JSON.parse(res.body));
      });
    };

    Gauges.prototype.post = function(path, body, cb) {
      if (body == null) body = {};
      return request.post(this.fullPath(path), this.reqOptions({
        body: body
      }), function(err, res) {
        return cb(JSON.parse(res.body));
      });
    };

    Gauges.prototype.put = function(path, body, cb) {
      if (body == null) body = {};
      return request.put(this.fullPath(path), this.reqOptions({
        body: body
      }), function(err, res) {
        return cb(JSON.parse(res.body));
      });
    };

    Gauges.prototype["delete"] = function(path, cb) {
      return request["delete"](this.fullPath(path), this.reqOptions, function(err, res) {
        return cb(JSON.parse(res.body));
      });
    };

    Gauges.prototype.fullPath = function(path) {
      return BASE_URI + path;
    };

    Gauges.prototype.reqOptions = function(hash) {
      if (hash == null) hash = {};
      hash.headers || (hash.headers = {});
      hash.headers['X-Gauges-Token'] = this.token();
      return hash;
    };

    return Gauges;

  })();

  module.exports = Gauges;

}).call(this);
